@@ -4,8 +4,7 @@ use warnings;
 use parent qw/Exporter/;
 use Plack::Request;
 use Plack::Response;
-# use Data::Section::Simple;
-use Router::Simple::Sinatraish;
+use Router::Simple::Sinatraish ();
 use Tiffany;
 
 our @EXPORT = qw/walk view_opt/;
@@ -23,17 +22,15 @@ sub view_opt {
 
 sub walk () {
     my $caller = caller(0);
-    # my $data_section = Data::Section::Simple->new($caller)->get_data_section // die;
     my $router = $caller->router;
-    my $tfall = Tiffany->load($view_class, @view_opt);
+    my $tiffany = Tiffany->load($view_class, @view_opt);
 
     sub {
         my $env = shift;
         my $req = Plack::Request->new($env);
-        my $c = Sinatraish::Context->new(req => $req, tfall => $tfall);
+        my $c = Sinatraish::Context->new(req => $req, tiffany => $tiffany);
         if ( my $route = $router->match($env) ) {
             $route->{code}->($c);
-            # use Data::Dumper; warn Dumper($c->res);
             return $c->res->finalize;
         }
         else {
@@ -44,7 +41,6 @@ sub walk () {
 
 package Sinatraish::Context;
 use Mouse;
-use Tiffany::TT;
 
 has req => (is => 'ro', isa => 'Plack::Request', required =>1);
 has res => (
@@ -52,16 +48,15 @@ has res => (
     isa     => 'Plack::Response',
     default => sub { Plack::Response->new(200, ['Content-Type' => 'text/html; charset=utf-8'], 'no content') }
 );
-has tfall => (
+has tiffany => (
     is => 'ro',
     isa => 'Object',
 );
-# has data_section => (is => 'ro', isa => 'HashRef');
 
 sub render {
     my ($self, $path, @args) = @_;
 
-    my $html = $self->tfall->render($path, @args);
+    my $html = $self->tiffany->render($path, @args);
     $self->res->header('Content-Length' => length($html));
     $self->res->body($html);
 }
